@@ -38,7 +38,7 @@ rasterToContour <- function(x, maxpixels=100000, ...) {
     for (i in 1:m) {
         res[[i]] <- Lines(.contourLines2LineList(cL[cLstack[[i]]]), ID = IDs[i])
     }
-    SL <- SpatialLines(res, proj4string = projection(x, asText=FALSE))
+    SL <- SpatialLines(res, proj4string = .getCRS((x)))
     SpatialLinesDataFrame(SL, data = df)
 	
 }
