@@ -8,7 +8,7 @@ setMethod('quantile', signature(x='Raster'),
 	function(x, ..., na.rm=TRUE, ncells=NULL) {
 		if (is.null(ncells)) {
 			v <- try ( getValues(x) )
-			if (class(v) == 'try-error') {
+			if (inherits(v, "try-error")) {
 				stop('raster too large. You can sample it with argument "ncells"')
 			}
 		} else {
@@ -17,7 +17,7 @@ setMethod('quantile', signature(x='Raster'),
 			} else {
 				v <- try ( sampleRandom(x, ncells) ) 
 			}
-			if (class(v) == 'try-error') {
+			if (inherits(v, "try-error")) {
 				stop('ncells too large')
 			}
 		}
@@ -27,6 +27,8 @@ setMethod('quantile', signature(x='Raster'),
 		if (nlayers(x)==1) {
 			return(quantile(v, ...))
 		} else {
+			# t(apply(v, 2, quantile, na.rm=TRUE))
+
 			q <- stats::quantile(v[,1], ...)
 			for (i in 2:nlayers(x)) {
 				q <- rbind(q, stats::quantile(v[,i], ...))
