@@ -113,8 +113,76 @@
 
 
 
-.polygonsToRaster <- function(p, rstr, field, fun='last', background=NA, mask=FALSE, update=FALSE, updateValue="all", getCover=FALSE, filename="", silent=TRUE, ...) {
+.polygonsToRaster <- function(p, rstr, field, fun='last', background=NA, mask=FALSE, update=FALSE, updateValue="all", getCover=FALSE, filename="", silent=TRUE, faster=TRUE, ...) {
 
+
+	npol <- length(p@polygons)
+	pvals <- .getPutVals(p, field, npol, mask)
+	putvals <- pvals[,1]
+	if (ncol(pvals) > 1) {
+		rstr@data@isfactor <- TRUE
+		rstr@data@attributes <- list(pvals)
+		if (!is.character(fun)) {
+			stop('when rasterizing multiple fields you must use "fun=first" or "fun=last"')
+		} else if (!(fun %in% c('first', 'last'))) {
+			stop('when rasterizing multiple fields you must use "fun=first" or "fun=last"')
+		}
+	}
+
+
+	if (getCover) {
+		nc <- ncell(rstr)
+		# high precision for possibly small polygons
+		#https://stackoverflow.com/questions/53854910/issue-with-estimating-weighted-mean-from-raster-for-a-polygon-shape-in-r/
+		fctr <- ifelse(nc < 5, 100, ifelse(nc < 17, 20, 10))
+		rstr <- disaggregate(raster(rstr), fctr)
+		r <- .fasterize(p, rstr, rep(1, npol), background=0, datatype="INT1U") 
+		return( aggregate(r, fctr, mean, na.rm=TRUE, filename=filename, ...) )
+	} 
+	
+
+	
+	### new code
+	if (is.character(fun) && (ncol(pvals) == 1) && faster) {
+
+		if (fun == "last") {
+			if (mask || update) {
+				if (mask && update) stop("either use 'mask' OR 'update'")	
+				background = NA
+				r <- .fasterize(p, rstr, pvals[,1], background) 
+				if (! hasValues(r)) {
+					if (mask) { 
+						warning('there are no values to mask')
+					} else {
+						warning('there are no values to update')
+					}
+					return(r)
+				}
+				if (mask) {
+					r <- mask(rstr, r)
+				} else {
+					if (updateValue[1]=="all") {
+						r <- cover(r, rstr)
+					} else if (updateValue[1]=="NA") {
+						r <- cover(rstr, r, ...)
+					} else if (updateValue[1]=="!NA") {
+						r <- mask(cover(r, rstr), rstr, ...)
+					} else {
+						s <- stack(r, rstr)
+						r <- overlay(rstr, r, fun=function(x,y){ i = (x %in% updateValue & !is.na(y)); x[i] <- y[i]; x }, ... )
+					}
+				}
+				return(r)
+			} else {
+				return( .fasterize(p, rstr, pvals[,1], background, filename, ...) )
+			}
+		}
+		
+	}
+	### end new code
+
+
+	
 	leftColFromX <- function ( object, x )	{
 		colnr <- (x - xmin(object)) / xres(object)
 		i <- colnr %% 1 == 0
@@ -140,13 +208,7 @@
 		filename <- rasterTmpFile()
 	}
 	
-	if (getCover) {
-#		fun <- 'first'
-#		mask <- FALSE
-#		update <- FALSE
-#		field <- -1
-		return (.polygoncover(p, rstr, filename, ...)) 		
-	}
+
 
 	if (mask & update) { 
 		stop('use either "mask" OR "update"')
@@ -167,7 +229,7 @@
 	rstr <- raster(rstr)
 	
 	if (!is.na(projection(p))) {
-		projection(rstr) <- projection(p)
+		projection(rstr) <-.getCRS(p)
 	}
 
 # check if bbox of raster and p overlap
@@ -203,10 +265,10 @@
 		}
 	}
 	
-	polinfo <- matrix(NA, nrow=npol * 2, ncol=6)
+	polinfo <- data.frame(matrix(NA, nrow=npol * 2, ncol=6))
 	colnames(polinfo) <- c('part', 'miny', 'maxy', 'value', 'hole', 'object')
-	addpol <- matrix(NA, nrow=500, ncol=6)
-
+	addpol <- polinfo[rep(1, 500), ]
+	rownames(addpol) <- NULL
 	pollist <- list()
 	cnt <- 0
 	for (i in 1:npol) {
@@ -349,13 +411,16 @@
 				}	
 								
 				if (updateHoles) {
+					updateHoles <- FALSE
 					rvtmp[holes < 1] <- NA
 					vals <- cbind(vals, rvtmp)
 					rvtmp <- rv1
+					holes <- holes1
 				}	
 			}
 		}	
 		
+		#print(vals)
 		
 		rrv <- rv1
 		if (!is.null(vals)) {
@@ -412,13 +477,15 @@
 #plot( .polygonsToRaster(p, rstr) )
 
 
-.polygoncover <- function(p, x, filename, ...) {
+...polygoncover <- function(p, x, filename, ...) {
 	d <- disaggregate(raster(x), 10)
 	r <- .polygonsToRaster(p, d, filename=filename, field=1, fun='first', background=0, mask=FALSE, update=FALSE, getCover=FALSE, silent=TRUE, ...)
 	aggregate(r, 10, sum)
+	
+	
+	
 } 
 
-
 .Old_polygoncover <- function(rstr, filename, polinfo, lxmin, lxmax, pollist, ...) {
 # percentage cover per grid cell
 
@@ -432,7 +499,7 @@
 	nc <- ncol(bigraster) * f
 	rv1 <- rep(0, nc)
 	holes1 <- rep(0, nc)
-	prj <- projection(bigraster)
+	prj <-.getCRS(bigraster)
 	hr <- 0.5 * yres(bigraster)
 
 	vv <- matrix(ncol=f, nrow=nc)
