@@ -45,7 +45,8 @@ function(x, ..., bands=NULL, varname="", native=FALSE, RAT=TRUE, quick=FALSE) {
 		if (length(rlist) == 1) {
 			return(.stackCDF(x, varname=varname, bands=bands))
 		} else {
-			s <- stack(sapply(rlist, function(x) raster(x, varname=varname, bands=bands)))
+			s <- stack(sapply(rlist, function(i) stack(i, varname=varname, bands=bands)))
+			return(s)
 		}
 		
 	} else {
@@ -93,7 +94,7 @@ function(x, bands=NULL, native=FALSE, RAT=TRUE, ...) {
 				s@nrows <- x[[1]]@nrows
 				s@ncols <- x[[1]]@ncols
 				s@extent <- x[[1]]@extent
-				s@crs <- x[[1]]@crs
+				crs(s) <- crs(x[[1]])
 				return(s)
 			}
 			warning('RasterLayer objects without cell values were removed')
@@ -106,7 +107,7 @@ function(x, bands=NULL, native=FALSE, RAT=TRUE, ...) {
 		s@nrows <- x[[1]]@nrows
 		s@ncols <- x[[1]]@ncols
 		s@extent <- x[[1]]@extent
-		s@crs <- x[[1]]@crs
+		crs(s) <- crs(x[[1]])
 		s@layers <- x
 		if (namesFromList) {
 			names(s) <- lstnames
@@ -206,7 +207,7 @@ function(x, bands=NULL, native=FALSE, RAT=TRUE, ...) {
 			x@nrows <- r@nrows
 			x@ncols <- r@ncols
 			x@extent <- r@extent
-			x@crs <- r@crs
+			crs(x) <- crs(r)
 			if(rotated(r)) {
 				x@rotated = r@rotated
 				x@rotation = r@rotation
